GlowElement

Enum GlowElement 

pub enum GlowElement {
    Node(GlowNode),
    Parameter(GlowParameter),
    Function(GlowFunction),
    Matrix(GlowMatrix),
    Command(GlowCommand),
    QualifiedNode(EmberPath, GlowNode),
    QualifiedParameter(EmberPath, GlowParameter),
    QualifiedFunction(EmberPath, GlowFunction),
    QualifiedMatrix(EmberPath, GlowMatrix),
    Template(GlowTemplate),
}
A Glow element (can be a node, parameter, function, matrix, or command).

Variants



Node(GlowNode)

A node in the tree



Parameter(GlowParameter)

A parameter



Function(GlowFunction)

A function



Matrix(GlowMatrix)

A matrix



Command(GlowCommand)

A command



QualifiedNode(EmberPath, GlowNode)

A qualified node (with path)



QualifiedParameter(EmberPath, GlowParameter)

A qualified parameter (with path)



QualifiedFunction(EmberPath, GlowFunction)

A qualified function (with path)



QualifiedMatrix(EmberPath, GlowMatrix)

A qualified matrix (with path)



Template(GlowTemplate)

A template

Implementations

Source

impl GlowElement

pub fn number(&self) -> Option<i32>

Get the element number if this is a numbered element.

pub fn path(&self) -> Option<&EmberPath>

Get the path if this is a qualified element.

pub fn is_node(&self) -> bool

Check if this is a node.

pub fn is_parameter(&self) -> bool

Check if this is a parameter.

pub fn is_function(&self) -> bool

Check if this is a function.

pub fn is_matrix(&self) -> bool

Check if this is a matrix.

pub fn is_command(&self) -> bool

Check if this is a command.