CommandBuilder

Struct CommandBuilder 

pub struct CommandBuilder;
Command builder for creating Glow commands.

Implementations

Source

impl CommandBuilder

pub fn get_root_directory() -> GlowElement

Create a GetDirectory command for the root.

pub fn subscribe() -> GlowElement

Create a Subscribe command.

pub fn unsubscribe() -> GlowElement

Create an Unsubscribe command.

pub fn invoke(invocation_id: i32, arguments: Vec<EmberValue>) -> GlowElement

Create an Invoke command.

pub fn get_directory_at_path(path: &EmberPath) -> Vec<GlowElement>

Create a command to get directory at a specific path.

pub fn get_directory_at_path_with_info( path: &EmberPath, identifier: Option<&str>, ) -> Vec<GlowElement>

Create a command to get directory at a specific path with node info.

pub fn subscribe_at_path(path: &EmberPath) -> Vec<GlowElement>

Create a command to subscribe at a specific path.

pub fn unsubscribe_at_path(path: &EmberPath) -> Vec<GlowElement>

Create a command to unsubscribe at a specific path.

pub fn set_value_at_path( path: &EmberPath, value: EmberValue, ) -> Vec<GlowElement>

Create a setValue command for a parameter at a path.

pub fn invoke_at_path( path: &EmberPath, invocation_id: i32, arguments: Vec<EmberValue>, ) -> Vec<GlowElement>

Create an invoke command for a function at a path.

pub fn matrix_connect( path: &EmberPath, target: i32, sources: Vec<i32>, operation: ConnectionOperation, ) -> Vec<GlowElement>

Create a matrix connection operation.