TreeNode

Struct TreeNode 

pub struct TreeNode { /* private fields */ }
A node in the Ember+ tree.

Implementations

Source

impl TreeNode

pub fn new_node(number: i32) -> Self

Create a new container node.

pub fn new_parameter(number: i32, value: EmberValue) -> Self

Create a new parameter node.

pub fn number(&self) -> i32

Get the node number.

pub fn contents(&self) -> &NodeContents

Get the node contents.

pub fn contents_mut(&mut self) -> &mut NodeContents

Get mutable node contents.

pub fn identifier(&self) -> Option<&str>

Get the identifier.

pub fn description(&self) -> Option<&str>

Get the description.

pub fn is_node(&self) -> bool

Check if this is a container node.

pub fn is_parameter(&self) -> bool

Check if this is a parameter.

pub fn is_function(&self) -> bool

Check if this is a function.

pub fn is_matrix(&self) -> bool

Check if this is a matrix.

pub fn value(&self) -> Option<&EmberValue>

Get the parameter value if this is a parameter.

pub fn set_value(&mut self, new_value: EmberValue)

Set the parameter value.

pub fn add_child(&mut self, child: TreeNodeRef)

Add a child node.

pub fn get_child(&self, number: i32) -> Option<TreeNodeRef>

Get a child by number.

pub fn children(&self) -> impl Iterator<Item = &TreeNodeRef>

Get all children.

pub fn update_from_glow_node(&mut self, glow: &GlowNode)

Update from a Glow node.

pub fn update_from_glow_parameter(&mut self, glow: &GlowParameter)

Update from a Glow parameter.

pub fn update_from_glow_function(&mut self, glow: &GlowFunction)

Update from a Glow function.

pub fn update_from_glow_matrix(&mut self, glow: &GlowMatrix)

Update from a Glow matrix.

pub fn to_glow_element(&self) -> GlowElement

Convert to a Glow element (non-qualified, for nested children).

pub fn to_qualified_glow_element(&self, path: &EmberPath) -> GlowElement

Convert to a qualified Glow element with full path. This is the correct format for server responses.