pub struct CommandBuilder;Expand description
Command builder for creating Glow commands.
Implementations
Sourceimpl CommandBuilder
impl CommandBuilder
Sourcepub fn get_root_directory() -> GlowElement
pub fn get_root_directory() -> GlowElement
Create a GetDirectory command for the root.
Sourcepub fn subscribe() -> GlowElement
pub fn subscribe() -> GlowElement
Create a Subscribe command.
Sourcepub fn unsubscribe() -> GlowElement
pub fn unsubscribe() -> GlowElement
Create an Unsubscribe command.
Sourcepub fn invoke(invocation_id: i32, arguments: Vec<EmberValue>) -> GlowElement
pub fn invoke(invocation_id: i32, arguments: Vec<EmberValue>) -> GlowElement
Create an Invoke command.
Sourcepub fn get_directory_at_path(path: &EmberPath) -> Vec<GlowElement>
pub fn get_directory_at_path(path: &EmberPath) -> Vec<GlowElement>
Create a command to get directory at a specific path.
Sourcepub fn get_directory_at_path_with_info(
path: &EmberPath,
identifier: Option<&str>,
) -> Vec<GlowElement>
pub fn get_directory_at_path_with_info( path: &EmberPath, identifier: Option<&str>, ) -> Vec<GlowElement>
Create a command to get directory at a specific path with node info.
Sourcepub fn subscribe_at_path(path: &EmberPath) -> Vec<GlowElement>
pub fn subscribe_at_path(path: &EmberPath) -> Vec<GlowElement>
Create a command to subscribe at a specific path.
Sourcepub fn unsubscribe_at_path(path: &EmberPath) -> Vec<GlowElement>
pub fn unsubscribe_at_path(path: &EmberPath) -> Vec<GlowElement>
Create a command to unsubscribe at a specific path.
Sourcepub fn set_value_at_path(
path: &EmberPath,
value: EmberValue,
) -> Vec<GlowElement>
pub fn set_value_at_path( path: &EmberPath, value: EmberValue, ) -> Vec<GlowElement>
Create a setValue command for a parameter at a path.
Sourcepub fn invoke_at_path(
path: &EmberPath,
invocation_id: i32,
arguments: Vec<EmberValue>,
) -> Vec<GlowElement>
pub fn invoke_at_path( path: &EmberPath, invocation_id: i32, arguments: Vec<EmberValue>, ) -> Vec<GlowElement>
Create an invoke command for a function at a path.
Sourcepub fn matrix_connect(
path: &EmberPath,
target: i32,
sources: Vec<i32>,
operation: ConnectionOperation,
) -> Vec<GlowElement>
pub fn matrix_connect( path: &EmberPath, target: i32, sources: Vec<i32>, operation: ConnectionOperation, ) -> Vec<GlowElement>
Create a matrix connection operation.